package liste_articles_ini;

/**
 * 
 * @author santini
 * 
 * Définition et gestion d'un article.
 *
 */
public class Article {
	
	private final String denomination ;
	private Double prix ;
	
	/**
	 * Constructeur champ à champ.
	 * 
	 * @param denom la dénomination de l'article (ex. Vélo).
	 * @param p le prix de l'article.
	 * @throws DenominationException dans le cas ou la dénomination donnée lors de l'initialisation ne suit pas le format attendu limité à 30 caractères.
	 * @throws PrixException dans le cas ou le prix donné lors de l'initiamlisation ne suit pas le format attendu : un prix est positif ou nul.
	 */
	public Article(String denom, Double p) throws DenominationException,PrixException {
		if (denom.length()<=30) {
			this.denomination = denom;
		} else {
			throw new DenominationException("La description de la dénomination ne doit pas excéder 30 caractères",denom);
		}
		this.setPrix(p) ;
	}
	
	/**
	 * Setter : Modifie le prix d'un article.
	 * @param new_prix le nouveau prix de l'article.
	 */
	public void setPrix(Double new_prix) throws PrixException {
		if (new_prix>=0) {
			this.prix = new_prix ;
		} else {
			throw new PrixException("Les prix négatifs ne sont pas autorisés.",new_prix);
		}
	}
	
	/**
	 * Getter : accès au prix de l'article.
	 * @return le prix de l'article.
	 */
	public Double getPrix() {
		return this.prix;
	}
	
	/**
	 * Getter : accès à la dénomination de l'article.
	 * @return la dénomination de l'article.
	 */
	public String getDenomination() {
		return this.denomination;
	}
	
	/**
	 * Redéfinition de la méthode pour la classe Article.
	 * @return la chaîne de caractères formatée décrivant un article.
	 */
	public String toString() {
		return String.format("%30s\t%10.2f", this.getDenomination(),this.getPrix());
	}
}
